@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::str::str_normalize_cryptoexchange_account;
 
-our $DATE = '2018-05-31'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-06-04'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,9 +9,9 @@ use warnings;
 
 sub meta {
     +{
-        v => 2,
+        v => 3,
         enable_by_default => 0,
-        might_die => 1,
+        might_fail => 1,
         prio => 50,
     };
 }
@@ -28,11 +28,11 @@ sub coerce {
     $res->{expr_coerce} = join(
         "",
         "do { my (\$xch, \$acc); $dt =~ m!(.+)/(.+)! and (\$xch, \$acc) = (\$1, \$2) or (\$xch, \$acc) = ($dt, 'default'); ",
-        "\$acc =~ /\\A[A-Za-z0-9_-]+\\z/ or die 'Invalid account syntax: ' . \$acc . ', please only use letters/numbers/underscores/dashes'; ",
-        "my \$cat = CryptoExchange::Catalog->new; my \@data = \$cat->all_data; ",
-        "my \$lc = lc(\$xch); my \$rec; for (\@data) { if (defined(\$_->{code}) && \$lc eq lc(\$_->{code}) || \$lc eq lc(\$_->{name}) || \$lc eq \$_->{safename}) { \$rec = \$_; last } } ",
-        "unless (\$rec) { die 'Unknown cryptoexchange code/name/safename: ' . \$lc } ",
-        "qq(\$rec->{safename}/\$acc) }",
+        "if (\$acc !~ /\\A[A-Za-z0-9_-]+\\z/) { [qq(Invalid account syntax (\$acc), please only use letters/numbers/underscores/dashes)] } ",
+        "else { my \$cat = CryptoExchange::Catalog->new; my \@data = \$cat->all_data; ",
+        "  my \$lc = lc(\$xch); my \$rec; for (\@data) { if (defined(\$_->{code}) && \$lc eq lc(\$_->{code}) || \$lc eq lc(\$_->{name}) || \$lc eq \$_->{safename}) { \$rec = \$_; last } } ",
+        "  if (!\$rec) { ['Unknown cryptoexchange code/name/safename: ' . \$lc] } else { [undef, qq(\$rec->{safename}/\$acc)] } ",
+        "} }",
     );
 
     $res;
@@ -53,7 +53,7 @@ Data::Sah::Coerce::perl::str::str_normalize_cryptoexchange_account - Normalize c
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::str::str_normalize_cryptoexchange_account (from Perl distribution Data-Sah-CoerceBundle-App-cryp), released on 2018-05-31.
+This document describes version 0.003 of Data::Sah::Coerce::perl::str::str_normalize_cryptoexchange_account (from Perl distribution Data-Sah-CoerceBundle-App-cryp), released on 2018-06-04.
 
 =head1 DESCRIPTION
 
